@@ -4,7 +4,7 @@
 # See LICENSE file for full license.
 
 from . import AWSHelperFn, AWSObject, AWSProperty
-from .validators import integer, positive_integer
+from .validators import boolean, integer, positive_integer
 
 
 EC2_INSTANCE_LAUNCH = "autoscaling:EC2_INSTANCE_LAUNCH"
@@ -42,6 +42,7 @@ class AutoScalingGroup(AWSObject):
         'DesiredCapacity': (integer, False),
         'HealthCheckGracePeriod': (int, False),
         'HealthCheckType': (basestring, False),
+        'InstanceId': (basestring, False),
         'LaunchConfigurationName': (basestring, True),
         'LoadBalancerNames': (list, False),
         'MaxSize': (positive_integer, True),
@@ -66,12 +67,13 @@ class LaunchConfiguration(AWSObject):
     type = "AWS::AutoScaling::LaunchConfiguration"
 
     props = {
-        'AssociatePublicIpAddress': (bool, False),
+        'AssociatePublicIpAddress': (boolean, False),
         'BlockDeviceMappings': (list, False),
-        'EbsOptimized': (bool, False),
+        'EbsOptimized': (boolean, False),
         'IamInstanceProfile': (basestring, False),
         'ImageId': (basestring, True),
-        'InstanceMonitoring': (bool, False),
+        'InstanceId': (basestring, False),
+        'InstanceMonitoring': (boolean, False),
         'InstanceType': (basestring, True),
         'KernelId': (basestring, False),
         'KeyName': (basestring, False),
@@ -93,6 +95,20 @@ class ScalingPolicy(AWSObject):
     }
 
 
+class ScheduledAction(AWSObject):
+    type = "AWS::AutoScaling::ScheduledAction"
+
+    props = {
+        'AutoScalingGroupName': (basestring, True),
+        'DesiredCapacity': (integer, False),
+        'EndTime': (basestring, True),
+        'MaxSize': (integer, False),
+        'MinSize': (integer, False),
+        'Recurrence': (basestring, True),
+        'StartTime': (basestring, True),
+    }
+
+
 class Trigger(AWSObject):
     type = "AWS::AutoScaling::Trigger"
 
