@@ -6,6 +6,12 @@
 from . import AWSObject, AWSProperty
 
 
+WebServer = "WebServer"
+Worker = "Worker"
+WebServerType = "Standard"
+WorkerType = "SQS/HTTP"
+
+
 class SourceBundle(AWSProperty):
     props = {
         'S3Bucket': (basestring, True),
@@ -49,6 +55,28 @@ class Application(AWSObject):
     }
 
 
+def validate_tier_name(name):
+    valid_names = [WebServer, Worker]
+    if name not in valid_names:
+        raise ValueError('Tier name needs to be one of %r' % valid_names)
+    return name
+
+
+def validate_tier_type(tier_type):
+    valid_types = [WebServerType, WorkerType]
+    if tier_type not in valid_types:
+        raise ValueError('Tier type needs to be one of %r' % valid_types)
+    return tier_type
+
+
+class Tier(AWSProperty):
+    props = {
+        'Name': (validate_tier_name, False),
+        'Type': (validate_tier_type, False),
+        'Version': (basestring, False),
+    }
+
+
 class Environment(AWSObject):
     type = "AWS::ElasticBeanstalk::Environment"
 
@@ -61,5 +89,6 @@ class Environment(AWSObject):
         'OptionsToRemove': (list, False),
         'SolutionStackName': (basestring, False),
         'TemplateName': (basestring, False),
+        'Tier': (Tier, False),
         'VersionLabel': (basestring, False),
     }
